# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import common
from . import test_payulatam
